package com.ruoyi.web.controller.ehs;

import java.util.List;
import java.util.Arrays;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ehsDocTransfer.domain.EhsDocTransfer;
import com.ruoyi.ehsDocTransfer.service.IEhsDocTransferService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 公文流转Controller
 *
 * @author ruoyi
 * @date 2023-12-07
 */
@Api(tags = "公文流转管理")
@RestController
@RequestMapping("/ehs/ehsDocTransfer")
public class EhsDocTransferController extends BaseController {
    @Autowired
    private IEhsDocTransferService ehsDocTransferService;

    /**
     * 查询公文流转列表
     */
    @GetMapping("/list")
    public TableDataInfo list(EhsDocTransfer ehsDocTransfer) {
        startPage();
        List<EhsDocTransfer> list = ehsDocTransferService.selectEhsDocTransferList(ehsDocTransfer);
        return getDataTable(list);
    }

    /**
     * 导出公文流转列表
     */
    @Log(title = "公文流转", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EhsDocTransfer ehsDocTransfer) {
        List<EhsDocTransfer> list = ehsDocTransferService.selectEhsDocTransferList(ehsDocTransfer);
        ExcelUtil<EhsDocTransfer> util = new ExcelUtil<EhsDocTransfer>(EhsDocTransfer.class);
        util.exportExcel(response, list, "公文流转数据");
    }

    /**
     * 获取公文流转详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(ehsDocTransferService.selectEhsDocTransferById(id));
    }

    /**
     * 新增公文流转
     */
    @ApiOperation("新增公文流转")
    @Log(title = "公文流转", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EhsDocTransfer ehsDocTransfer) {
        return toAjax(ehsDocTransferService.save(ehsDocTransfer));
    }

    /**
     * 修改公文流转
     */
    @ApiOperation("修改公文流转")
    @Log(title = "公文流转", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EhsDocTransfer ehsDocTransfer) {
        return toAjax(ehsDocTransferService.updateById(ehsDocTransfer));
    }

    /**
     * 删除公文流转
     */
    @ApiOperation("删除公文流转")
    @Log(title = "公文流转", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(ehsDocTransferService.removeByIds(Arrays.asList(ids)));
    }
}
